@@ -1,7 +1,7 @@
 #ifnotequal.pm
-#Last Change: 2008-12-28
-#Copyright (c) 2006 Marc-Seabstian "Maluku" Lucksch
-#Version 0.1
+##Last Change: 2009-01-19
+#Copyright (c) 2009 Marc-Seabstian "Maluku" Lucksch
+#Version 0.3
 ####################
 #This file is part of the Dotiac::DTL project. 
 #http://search.cpan.org/perldoc?Dotiac::DTL
@@ -63,9 +63,9 @@ sub perl {
 	my $id=shift;
 	$self->SUPER::perl($fh,$id,@_);
 	print $fh "my ";
-	print $fh Data::Dumper->Dump([$self->{var1}],["\$vara$id"]);
+	print $fh (Data::Dumper->Dump([$self->{var1}],["\$vara$id"]));
 	print $fh "my ";
-	print $fh Data::Dumper->Dump([$self->{"var2"}],["\$varb$id"]);
+	print $fh (Data::Dumper->Dump([$self->{"var2"}],["\$varb$id"]));
 	$id = $self->{true}->perl($fh,$id+1,@_);
 	$id = $self->{false}->perl($fh,$id+1,@_) if $self->{false};
 	return $self->{n}->perl($fh,$id+1,@_)
